<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="所属年度">
              <el-date-picker v-model="querys[0].value" placeholder="请选择所属年度" style="width:100%;" type="year"
                              value-format="yyyy" />
              <!-- <el-input clearable placeholder="请输入所属目标" v-model="querys[0].value" /> -->
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="考核人">
              <el-input v-model="querys[1].value" clearable placeholder="请输入考核人" />
            </el-form-item>
          </el-col>
          <!--          <el-col :span="7">-->
          <!--            <el-form-item label="考核时间">-->
          <!--              <el-date-picker v-model="querys[2].value" clearable end-placeholder="结束日期" range-separator="至"-->
          <!--                              start-placeholder="开始日期"-->
          <!--                              style="width: 100%;" type="daterange"-->
          <!--                              value-format="yyyy-MM-dd"></el-date-picker>-->
          <!--            </el-form-item>-->
          <!--          </el-col>-->
          <el-col :span="4">
            <el-button icon="el-icon-search" type="primary" @click="handleSearch">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div ref="contentPanel" class="bbsl-table-content">
      <div ref="btnPanel" class="bbsl-btn-content">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete"
                     style="margin-left: 10px"
                     type="danger">删除
          </el-button>
        </el-popconfirm>
      </div>
      <el-table ref="multipleSelection" v-loading="loading" :cell-style="{ 'text-align': 'center' }" :data="tableData"
                :header-cell-style="{ 'text-align': 'center' }"
                :max-height="tableMaxHeight" :style="{ width: '100%' }" border
                size="mini" @row-dblclick="handleDbClick"
                @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column fixed label="序号" type="index" width="55"></el-table-column>
        <el-table-column fixed label="所属年度" prop="checkYear" show-overflow-tooltip sortable></el-table-column>
        <el-table-column fixed label="考核项目" prop="checkItem" show-overflow-tooltip>
        </el-table-column>
        <el-table-column fixed label="考核类型" prop="checkType" show-overflow-tooltip>
        </el-table-column>
        <el-table-column fixed label="考核人" prop="assessor" show-overflow-tooltip></el-table-column>
        <el-table-column fixed label="考核结果" prop="checkResult" show-overflow-tooltip>
        </el-table-column>
        <el-table-column fixed label="考核评价" prop="assessment" show-overflow-tooltip>
        </el-table-column>
        <el-table-column fixed label="考核分数" prop="score" show-overflow-tooltip>
        </el-table-column>
        <el-table-column fixed label="考核等级" prop="grade" show-overflow-tooltip>
        </el-table-column>
        <el-table-column fixed label="考核时间" prop="assessorDate" show-overflow-tooltip sortable>
        </el-table-column>
      </el-table>
      <el-pagination ref="paginationPanel" :current-page="queryParam.pageBean.page"
                     :page-size="queryParam.pageBean.pageSize" :page-sizes="[20, 30, 40, 50]"
                     :total="total" align="right"
                     background
                     class="bbsl-pagination" layout="total, sizes, prev, pager, next, jumper"
                     @size-change="handleSizeChange" @current-change="handleCurrentChange"></el-pagination>
    </div>
    <SafetyTrainingAssessmentDialog ref="formModal"></SafetyTrainingAssessmentDialog>
  </div>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'

import CmgtSaftyAppraisalApi from '@/views/Manage/saftyPlan/api/CmgtSaftyAppraisalApi'
import SafetyTrainingAssessmentDialog from '@/views/Manage/saftyTraining/components/SafetyTrainingAssessmentDialog.vue'

export default {
  name: 'CmgtSaftyAppraisalManage',
  components: {
    SafetyTrainingAssessmentDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/manager/cmgtSaftyCheck/delete'
      },
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'check_year_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'assessor_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'assessor_date_',
          relation: 'AND',
          value: ''
        }
      ],
      StshowFormDias: false,
      fuelTypes: [],
      // 写死的表格数据
      tableData: [
        {
          id: 1,
          checkYear: '2024',
          checkItem: '安全生产责任制',
          checkType: '培训讲师',
          assessor: '张三',
          checkResult: '合格',
          assessment: '表现优秀，各项指标达标',
          score: '95',
          grade: 'A',
          assessorDate: '2023-03-15'
        },
        {
          id: 2,
          checkYear: '2024',
          checkItem: '安全操作规程',
          checkType: '培训对象',
          assessor: '李四',
          checkResult: '合格',
          assessment: '操作规范，安全意识强',
          score: '90',
          grade: 'A-',
          assessorDate: '2023-03-10'
        },
        {
          id: 3,
          checkYear: '2024',
          checkItem: '应急预案',
          checkType: '培训对象',
          assessor: '王五',
          checkResult: '良好',
          assessment: '预案完善，但演练不足',
          score: '85',
          grade: 'B+',
          assessorDate: '2023-03-20'
        },
        {
          id: 4,
          checkYear: '2024',
          checkItem: '安全培训',
          checkType: '培训讲师',
          assessor: '赵六',
          checkResult: '合格',
          assessment: '培训覆盖全面，效果良好',
          score: '92',
          grade: 'A-',
          assessorDate: '2023-03-25'
        },
        {
          id: 5,
          checkYear: '2024',
          checkItem: '设备安全检查',
          checkType: '培训组织',
          assessor: '钱七',
          checkResult: '优秀',
          assessment: '检查细致，问题整改及时',
          score: '98',
          grade: 'A+',
          assessorDate: '2023-03-05'
        }
      ],
      total: 5 // 总条数
    }
  },
  created() {
  },
  mounted() {
  },
  methods: {
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      // this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      CmgtSaftyAppraisalApi.loadCmgtSaftyAppraisal(this.queryParam, res => {
        //console.log(res, 'res')
        // this.total = res.total
        // 目前使用死数据
        // this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    },
    // 修改
    handleUpdate(row) {
      console.log(row.id)
      this.$refs.formModal.Update(row)
    },
    // 关联设备
    // handleClick(item) {
    //   console.log(item.id)
    //   this.StshowFormDias = true
    // },
    closeStshowForm() {
      this.StshowFormDias = false
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
